@@ -1,8 +1,7 @@
 
 import django_couch
 from django.conf import settings
-
-from django.contrib.auth.models import check_password, get_hexdigest
+from django_couch.auth.utils import check_password
 from django_couch.auth.models import User
 from couchdbcurl.client import ResourceNotFound
     
