@@ -1,9 +1,7 @@
+
 from datetime import datetime
 from couchdbcurl.client import Document
-
-import random
-        
-
+from django_couch.auth.utils import make_password, check_password
 
 class User(Document):
 
@@ -90,28 +88,7 @@ Example:
             self.backend = backend
 
     def set_password(self, raw_password):
-        """This is copy-paste from django.contrib.auth.models.User.set_password()"""
-
-        # I need this in runtime, not install time
-        from django.contrib.auth.models import get_hexdigest, check_password
+        self.password = make_password(raw_password)
         
-        algo = 'sha1'
-        salt = get_hexdigest(algo, str(random.random()), str(random.random()))[:5]
-        hsh = get_hexdigest(algo, salt, raw_password)
-        self.password = '%s$%s$%s' % (algo, salt, hsh)
-        
-
     def check_password(self, raw_password):
-        """
-        Returns a boolean of whether the raw_password was correct. Handles
-        encryption formats behind the scenes.
-
-        (c) django.contrib.auth.models.User.check_password()
-        """
-        
-        # I need this in runtime, not install time
-        from django.contrib.auth.models import get_hexdigest, check_password
-        
-        # Backwards-compatibility check. Older passwords won't include the
-        # algorithm or salt.
         return check_password(raw_password, self.password)
